"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createUseCssAndCx = exports.createCssAndCxFactory = void 0;
require("./tools/Object.fromEntries");
const classnames_1 = require("./tools/classnames");
const useSemanticGuaranteeMemo_1 = require("./tools/useSemanticGuaranteeMemo");
exports.createCssAndCxFactory = (() => {
    function createMerge(params) {
        const { getRegisteredStyles } = params;
        function merge(registered, css, className) {
            const registeredStyles = [];
            const rawClassName = getRegisteredStyles(registered, registeredStyles, className);
            if (registeredStyles.length < 2) {
                return className;
            }
            return rawClassName + css(registeredStyles);
        }
        return { merge };
    }
    function createCssAndCxFactory(params) {
        const { serializeStyles, insertStyles, getRegisteredStyles } = params;
        const { merge } = createMerge({ getRegisteredStyles });
        function cssAndCxFactory(params) {
            const { cache } = params;
            const css = (...args) => {
                const serialized = serializeStyles(args, cache.registered);
                insertStyles(cache, serialized, false);
                return `${cache.key}-${serialized.name}`;
            };
            const cx = (...args) => merge(cache.registered, css, classnames_1.classnames(args));
            return { css, cx };
        }
        return { cssAndCxFactory };
    }
    return { createCssAndCxFactory };
})().createCssAndCxFactory;
function createUseCssAndCx(params) {
    const { serializeStyles, insertStyles, getRegisteredStyles, useEmotionCache, } = params;
    const { cssAndCxFactory } = exports.createCssAndCxFactory({
        serializeStyles,
        insertStyles,
        getRegisteredStyles,
    });
    function useCssAndCx() {
        const cache = useEmotionCache();
        const { css, cx } = useSemanticGuaranteeMemo_1.useSemanticGuaranteeMemo(() => cssAndCxFactory({ cache }), [cache]);
        return { css, cx };
    }
    return { useCssAndCx };
}
exports.createUseCssAndCx = createUseCssAndCx;
//# sourceMappingURL=cssAndCx.js.map